summaryrefslogtreecommitdiff
path: root/src/gallium/include/pipe/p_shader_tokens.h
diff options
context:
space:
mode:
authorKeith Whitwell <keithw@vmware.com>2009-02-10 19:22:57 +0000
committerKeith Whitwell <keithw@vmware.com>2009-02-10 19:22:57 +0000
commit9c9ba66fbae8089e9423f6b09ad1091cccf9b006 (patch)
tree81ecce3d6b19e5b77fcf31e5f081e1c546f398b9 /src/gallium/include/pipe/p_shader_tokens.h
parentebb864da9e98003be9ea388013ae4385d341e46f (diff)
parent1e8177ee178b131afa86d874b062a8ae3fae0cca (diff)
Merge commit 'origin/gallium-0.2' into gallium-0.2
Conflicts: src/gallium/state_trackers/wgl/icd/stw_icd.c
Diffstat (limited to 'src/gallium/include/pipe/p_shader_tokens.h')
-rw-r--r--src/gallium/include/pipe/p_shader_tokens.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/gallium/include/pipe/p_shader_tokens.h b/src/gallium/include/pipe/p_shader_tokens.h
index ad43d799f3..35df70e7b7 100644
--- a/src/gallium/include/pipe/p_shader_tokens.h
+++ b/src/gallium/include/pipe/p_shader_tokens.h
@@ -64,7 +64,7 @@ struct tgsi_processor
struct tgsi_token
{
unsigned Type : 4; /**< TGSI_TOKEN_TYPE_x */
- unsigned Size : 8; /**< UINT */
+ unsigned NrTokens : 8; /**< UINT */
unsigned Padding : 19;
unsigned Extended : 1; /**< BOOL */
};
@@ -107,7 +107,7 @@ enum tgsi_file_type {
struct tgsi_declaration
{
unsigned Type : 4; /**< TGSI_TOKEN_TYPE_DECLARATION */
- unsigned Size : 8; /**< UINT */
+ unsigned NrTokens : 8; /**< UINT */
unsigned File : 4; /**< one of TGSI_FILE_x */
unsigned UsageMask : 4; /**< bitmask of TGSI_WRITEMASK_x flags */
unsigned Interpolate : 4; /**< one of TGSI_INTERPOLATE_x */
@@ -145,7 +145,7 @@ struct tgsi_declaration_semantic
struct tgsi_immediate
{
unsigned Type : 4; /**< TGSI_TOKEN_TYPE_IMMEDIATE */
- unsigned Size : 8; /**< UINT */
+ unsigned NrTokens : 8; /**< UINT */
unsigned DataType : 4; /**< one of TGSI_IMM_x */
unsigned Padding : 15;
unsigned Extended : 1; /**< BOOL */
@@ -442,7 +442,7 @@ struct tgsi_immediate_float32
struct tgsi_instruction
{
unsigned Type : 4; /* TGSI_TOKEN_TYPE_INSTRUCTION */
- unsigned Size : 8; /* UINT */
+ unsigned NrTokens : 8; /* UINT */
unsigned Opcode : 8; /* TGSI_OPCODE_ */
unsigned Saturate : 2; /* TGSI_SAT_ */
unsigned NumDstRegs : 2; /* UINT */
@@ -458,7 +458,7 @@ struct tgsi_instruction
*
* Then, tgsi_instruction::NumSrcRegs of tgsi_src_register follow.
*
* tgsi_instruction::Size contains the total number of words that make the
* instruction, including the instruction word.
*/
@@ -458,7 +458,7 @@ struct tgsi_instruction
* Then, tgsi_instruction::NumSrcRegs of tgsi_src_register follow.
*
- * tgsi_instruction::Size contains the total number of words that make the
+ * tgsi_instruction::NrTokens contains the total number of words that make the
* instruction, including the instruction word.
*/